#
# spec file for package 0ad
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# Enable NVTT only on arch supported by nvidia-texture-tools
%ifarch %{ix86} x86_64 ppc
%bcond_without enable_nvtt
%else
%bcond_with enable_nvtt
%endif

Name:           0ad
Version:        0.0.22
Release:        lp150.2.10
Summary:        A real-time strategy game of ancient warfare
License:        GPL-2.0+ and LGPL-3.0+ and CC-BY-SA-3.0 and MIT and ISC and MPL-2.0 and BSD-3-Clause
Group:          Amusements/Games/Strategy/Real Time
Url:            http://play0ad.com/
Source:         http://sourceforge.net/projects/zero-ad/files/releases/%{name}-%{version}-alpha-unix-build.tar.xz
Source99:       %{name}.changes
# PATCH-FEATURE-UPSTREAM system-tinygettext.patch -- http://trac.wildfiregames.com/ticket/4192
Patch1:         system-tinygettext.patch
# PATCH-FIX-UPSTREAM fix_abs_of_unsigned_char_on_arm.patch
Patch2:         https://github.com/0ad/0ad/commit/0133d6070bf4c4b2c18c79bf72b53af23403a36d.patch#/fix_abs_of_unsigned_char_on_arm.patch
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  libXcursor-devel
%if 0%{?suse_version} >= 1330
BuildRequires:  libboost_filesystem-devel
BuildRequires:  libboost_system-devel
%else
BuildRequires:  boost-devel
%endif
BuildRequires:  libjpeg-devel
BuildRequires:  libminiupnpc-devel
BuildRequires:  libpng-devel
BuildRequires:  nasm
%if %{with enable_nvtt}
BuildRequires:  nvidia-texture-tools
%endif
BuildRequires:  pkgconfig
BuildRequires:  python
BuildRequires:  update-desktop-files
BuildRequires:  wxWidgets-3_0-devel
BuildRequires:  pkgconfig(IL)
BuildRequires:  pkgconfig(gloox)
BuildRequires:  pkgconfig(icu-i18n)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libenet)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(mozjs-38)
BuildRequires:  pkgconfig(openal)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(tinygettext)
BuildRequires:  pkgconfig(vorbis)
BuildRequires:  pkgconfig(zlib)
Requires:       0ad-data = %{version}

%description
0 A.D. (pronounced "zero ey-dee") is a real-time strategy (RTS) game
of ancient warfare. It is a historically-based war/economy game that
allows players to relive or rewrite the history of Western
civilizations, focusing on the years between 500 B.C. and 500 A.D.
The project contains 3D graphics, detailed artwork, sound, and a
flexible game engine.

%prep
%setup -q -n %{name}-%{version}-alpha
%patch1 -p1
# Do not patch files not part of the distributed source
sed -i -e 's@[-+]\{3\}.*/binaries/@#\0@; s@diff .*/binaries/@#\0@' %{PATCH2}
%patch2 -p1

# Fix usage of __DATE__ and __TIME__ macros
modified="$(sed -n '/^----/n;s/ - .*$//;p;q' "%{SOURCE99}")"
DATE="\"$(date -d "${modified}" "+%%b %%e %%Y")\""
TIME="\"$(date -d "${modified}" "+%%T")\""
find . "(" -name '*.[ch]' -o -name '*.cpp' ")" -exec sed -i "s/__DATE__/${DATE}/g;s/__TIME__/${TIME}/g" \{\} +

%build
export CFLAGS="%{optflags}"
# bundled Collada uses CCFLAGS
export CCFLAGS="%{optflags}"
export CPPFLAGS="%{optflags} -fpermissive"
build/workspaces/update-workspaces.sh \
    %{?_smp_mflags} \
    --bindir=%{_bindir} \
    --datadir=%{_datadir}/%{name} \
    --libdir=%{_libdir}/%{name} \
%if %{with enable_nvtt}
    --with-system-nvtt \
%else
   --without-nvtt \
%endif
    --with-system-tinygettext \
    --with-system-mozjs38 \

pushd build/workspaces/gcc
make verbose=1 %{?_smp_mflags}
popd

%install
install -Dm 0755 binaries/system/ActorEditor %{buildroot}%{_bindir}/ActorEditor
install -Dm 0755 binaries/system/pyrogenesis %{buildroot}%{_bindir}/pyrogenesis
install -Dm 0755 binaries/system/libCollada.so %{buildroot}%{_libdir}/%{name}/libCollada.so
install -Dm 0755 binaries/system/libAtlasUI.so %{buildroot}%{_libdir}/%{name}/libAtlasUI.so

install -Dm 0644 build/resources/0ad.desktop %{buildroot}%{_datadir}/applications/%{name}.desktop
install -Dm 0644 build/resources/0ad.appdata.xml %{buildroot}%{_datadir}/appdata/%{name}.appdata.xml
install -Dm 0644 build/resources/0ad.png %{buildroot}%{_datadir}/pixmaps/%{name}.png

%suse_update_desktop_file %{name}

install -Dm 0755 build/resources/0ad.sh %{buildroot}%{_bindir}/0ad

mkdir -p %{buildroot}%{_libdir}/%{name}
mkdir -p %{buildroot}%{_datadir}/%{name}

%files
%defattr(-,root,root)
%doc README.txt
%license LICENSE.txt license_gpl-2.0.txt license_lgpl-2.1.txt license_mit.txt
%{_bindir}/0ad
%{_bindir}/pyrogenesis
%{_bindir}/ActorEditor
%{_libdir}/%{name}/
%{_datadir}/pixmaps/%{name}.png
%{_datadir}/appdata/%{name}.appdata.xml
%{_datadir}/applications/%{name}.desktop
%dir %{_libdir}/%{name}
%dir %{_datadir}/%{name}

%changelog
* Fri Mar  9 2018 stefan.bruens@rwth-aachen.de
- Keep fix_abs_of_unsigned_char_on_arm.patch intact and disable
  the conflicting/irrelevant hunk in the spec file
* Sun Feb 25 2018 stefan.bruens@rwth-aachen.de
- Revert the changes to use bundled mozjs38 on Leap 42.3 again
  (no changelog entry), it does not build on 42.3. Use fixed
  mozjs38 from distribution instead.
* Sat Feb 24 2018 stefan.bruens@rwth-aachen.de
- Add fix_abs_of_unsigned_char_on_arm.patch, fixes build on 32/64
  bit ARM (and probably PPC)
* Sat Feb  3 2018 guillaume@opensuse.org
- Enable nvidia-texture-tools only on supported archs
* Fri Feb  2 2018 stefan.bruens@rwth-aachen.de
- Use system mozjs38, bundled one fails to build on TW
- Remove special handling for Leap 42.1
- Pass compiler flags to bundled Collada
* Tue Nov 21 2017 adam.majer@suse.de
- Stop depending on boost-devel (boo#1062766)
* Fri Aug 11 2017 mailaender@opensuse.org
- Build with system nvidia-texture-tools (boo#1053393)
* Fri Jul 28 2017 dimstar@opensuse.org
- Update to version 0.0.22:
  + Remake of many models, animations and textures, two new music
    tracks.
  + Configuration-free Multiplayer Hosting.
  + Capture the Relic Gamemode.
  + Aura and Heal Range Visualization.
  + Twelve new maps, including scripted enemies, rising water and a
    tutorial.
  + Espionage Technology, Team Bonuses and Hero Auras.
  + Petra AI Diplomacy and Attack Strategies.
  + Summary Screen Graphs.
  + Cinema Path Editing.
  + Buddy System.
- Drop 0ad-desktop.patch: fixed upstream.
* Fri Feb 17 2017 dimstar@opensuse.org
- Install the upstream provided appdata.xml file.
* Wed Dec  7 2016 ecsos@opensuse.org
- Update to version 0.0.21
  See: https://play0ad.com/new-release-0-a-d-alpha-21-ulysses/
- Add patch 0ad-desktop.patch because of rpmlint-error invalid-
  desktopfile invalid key URL
- Drop patch fix-c++14-compat.patch because now in upstream
- Rebase patch system-tinygettext.patch
* Tue Aug 30 2016 rpm@fthiessen.de
- Added system-tinygettext.patch
- Removed code for other distributions from spec file, sine we just
  build for openSUSE.
* Fri Jul 29 2016 jengelh@inai.de
- Update License field and trim filler words from description.
* Mon Jun 27 2016 rpm@fthiessen.de
- Fixed build with gcc6 (Tumbleweed), added fix-c++14-compat.patch
* Mon May 16 2016 jengelh@inai.de
- Build with wxWidgets 3 and reenable dependency generation
* Mon Apr  4 2016 mvetter@suse.com
- Update to version 0.0.20
  * New maps
  * Better graphics and Camera
  See https://play0ad.com/new-release-0-a-d-alpha-20-timosthenes/
* Sat Apr  2 2016 bwiedemann@suse.com
- use changelog time instead of build time to fix build-compare
* Thu Nov 26 2015 mvetter@suse.com
- Update to version 0.0.19
* Tue Apr  7 2015 g.bluehut@gmail.com
- Use xz archive instead of gz
* Thu Apr  2 2015 opensuse@oeschti.de
- update to version 0.0.18
- use libminiupnpc-devel instead of builtin libminiupnpc
* Mon Oct 13 2014 opensuse@dstoecker.de
- update to version 0.0.17
* Sun Oct 12 2014 bwiedemann@suse.com
- use builtin libminiupnpc to work inspite of incompatible OS version
* Mon May 26 2014 adrian@suse.de
- require same versioned data package
* Wed May 21 2014 adrian@suse.de
- build using external libicu
* Tue May 20 2014 adrian@suse.de
- Update to version 0.0.16.
* Sat Jan  4 2014 aj@ajaissle.de
- Update to version 0.0.15.
* Tue Sep 10 2013 mailaender@opensuse.org
- Update to version 0.0.14.
- Adhere to https://en.opensuse.org/SourceUrls
* Wed Apr  3 2013 dimstar@opensuse.org
- Update to version 0.0.13.
* Sun Jan 13 2013 joop.boonen@opensuse.org
- Added BuildRequires libXcursor-devel as they are not
  automatically installed for openSUSE > 12.2
* Sun Dec 16 2012 philip@zaynar.co.uk
- Update to 0.0.12
- Remove obsolete unused Debian build scripts
* Sun Oct 14 2012 philip@zaynar.co.uk
- Update to 0.0.11
- New version number scheme
- Remove fam/gamin dependency
* Wed May 16 2012 philip@zaynar.co.uk
- Update to r11863
* Thu Mar 15 2012 philip@zaynar.co.uk
- Update to r11339
* Fri Dec 23 2011 philip@zaynar.co.uk
- Update to r10803
* Sat Sep 17 2011 philip@zaynar.co.uk
- Update to r10288
* Sun Jul 10 2011 philip@zaynar.co.uk
- Update to r9786
- libenet0-devel -> libenet-devel
* Fri May 20 2011 philip@zaynar.co.uk
- Update to r9530
- libenet-devel -> libenet0-devel
* Fri Mar 11 2011 philip@zaynar.co.uk
- Update to r9049
* Mon Feb 21 2011 reddwarf@opensuse.org
- wxGTK -> wxWidgets migration
* Fri Dec 10 2010 philip@zaynar.co.uk
- Update to r8832
* Sun Oct 17 2010 philip@zaynar.co.uk
- Update to r8413
* Sun Aug 15 2010 philip@zaynar.co.uk
- Update to r7970
- Compile in Release mode
* Mon Jul 12 2010 bitshuffler@opensuse.org
- Initial package
